EigenWhich

Enum EigenWhich 

pub enum EigenWhich {
    LargestMagnitude(usize),
    SmallestMagnitude(usize),
    LargestAlgebraic(usize),
    SmallestAlgebraic(usize),
    BothEnds(usize),
    LargestReal(usize),
    SmallestReal(usize),
    LargestImaginary(usize),
    SmallestImaginary(usize),
    All,
    Interval {
        low: f64,
        high: f64,
    },
    Select(Range<usize>),
}
Which eigenvalues to compute (igraph_eigen_which_t).

Counts must be between 1 and the order of the matrix. Not every choice is supported by every solver: the symmetric solvers accept the magnitude, algebraic, BothEnds, All, Interval and Select choices (the last three only with LAPACK); the non-symmetric solver accepts the magnitude, real part, imaginary part, All and Select choices.

Variants



LargestMagnitude(usize)

The given number of eigenvalues of largest magnitude.



SmallestMagnitude(usize)

The given number of eigenvalues of smallest magnitude.



LargestAlgebraic(usize)

The given number of largest (algebraic) eigenvalues; symmetric only.



SmallestAlgebraic(usize)

The given number of smallest (algebraic) eigenvalues; symmetric only.



BothEnds(usize)

The given number of eigenvalues, alternating from the two ends of the spectrum (largest first); symmetric only. LAPACK needs at least 2.



LargestReal(usize)

The given number of eigenvalues with largest real part; non-symmetric only.



SmallestReal(usize)

The given number of eigenvalues with smallest real part; non-symmetric only.



LargestImaginary(usize)

The given number of eigenvalues with largest imaginary part; non-symmetric only.



SmallestImaginary(usize)

The given number of eigenvalues with smallest imaginary part; non-symmetric only.



All

All the eigenvalues.



Interval

All the eigenvalues in the half-open interval (low, high]; symmetric LAPACK only.

Fields

low: f64

Exclusive lower bound.

high: f64

Inclusive upper bound.



Select(Range<usize>)

Eigenvalues by (zero-based) position: for symmetric matrices in increasing algebraic order, for non-symmetric ones in increasing magnitude. LAPACK only.