arpack_unpack_complex

Function arpack_unpack_complex 

pub fn arpack_unpack_complex(
    vectors: &Matrix,
    values: &Matrix,
    nev: usize,
) -> Result<(Matrix, Matrix)>
Rewrites the packed output of the non-symmetric ARPACK solver into a regular form (igraph_arpack_unpack_complex).

values is a k × 2 matrix of real and imaginary parts, vectors the packed eigenvector matrix (one column per real eigenvalue, two columns — real and imaginary part — per complex conjugate pair). The result keeps the first nev eigenvalues as an nev × 2 matrix, and returns an n × 2 nev eigenvector matrix where eigenvector k occupies columns 2k (real part) and 2k + 1 (imaginary part).

arpack_rnsolve already returns unpacked Complex vectors; this is useful to post-process raw data.

Binds igraph_arpack_unpack_complex.

Errors

If values does not have two columns, nev exceeds its rows, the packed vectors are too few, or a complex eigenvalue is not followed by its conjugate.