lapack_dgetrf

Function lapack_dgetrf 

pub fn lapack_dgetrf(a: &Matrix) -> Result<LuFactors>
LU factorization with partial pivoting of a general m × n matrix, A = P L U (igraph_lapack_dgetrf), where L is lower triangular (trapezoidal if m > n) with unit diagonal and U is upper triangular (trapezoidal if m < n).

A singular matrix is not an error: check LuFactors::info.

Binds igraph_lapack_dgetrf.