pub struct SparseElements {
pub i: Vec<i64>,
pub j: Vec<i64>,
pub x: Vec<f64>,
}Expand description
The elements of a sparse matrix as returned by
SparseMat::getelements (the raw CXSparse arrays).
Fields
i: Vec<i64>Row index of each stored element.
j: Vec<i64>For a triplet matrix: the column index of each stored element. For a
column-compressed matrix: the column pointers, of length ncol + 1;
the elements of column k are at positions j[k]..j[k + 1] of
i and x.
x: Vec<f64>The value of each stored element.