pub struct SpectralEmbedding {
pub x: Matrix,
pub y: Matrix,
pub d: Vec<f64>,
}Expand description
A spectral embedding of the vertices of a graph.
Fields
x: MatrixThe latent positions X (or the singular vectors U when not
scaled): one row per vertex, one column per dimension.
y: MatrixThe second half of the latent positions Y (or V), for directed
graphs; equal to x for undirected graphs.
d: Vec<f64>The eigenvalues (undirected) or singular values (directed) used; empty for graphs without edges.