pub enum ArpackWhich {
LargestMagnitude,
SmallestMagnitude,
LargestAlgebraic,
SmallestAlgebraic,
BothEnds,
LargestReal,
SmallestReal,
LargestImaginary,
SmallestImaginary,
}Expand description
Which eigenvalues ARPACK should compute (the which field of
igraph_arpack_options_t).
The first five are valid for symmetric problems (arpack_rssolve),
the magnitude-based and the real/imaginary-part-based ones for
non-symmetric problems (arpack_rnsolve).
Variants
LargestMagnitude
Largest magnitude ("LM"), the default; symmetric and non-symmetric.
SmallestMagnitude
Smallest magnitude ("SM"); symmetric and non-symmetric.
LargestAlgebraic
Largest algebraic value ("LA"); symmetric only.
SmallestAlgebraic
Smallest algebraic value ("SA"); symmetric only.
BothEnds
Half from each end of the spectrum, one more from the high end when
nev is odd ("BE"); symmetric only.
LargestReal
Largest real part ("LR"); non-symmetric only.
SmallestReal
Smallest real part ("SR"); non-symmetric only.
LargestImaginary
Largest imaginary part ("LI"); non-symmetric only.
SmallestImaginary
Smallest imaginary part ("SI"); non-symmetric only.
Implementations
Sourceimpl ArpackWhich
impl ArpackWhich
Sourcepub fn is_symmetric(self) -> bool
pub fn is_symmetric(self) -> bool
Whether this choice is valid for symmetric problems.
Sourcepub fn is_nonsymmetric(self) -> bool
pub fn is_nonsymmetric(self) -> bool
Whether this choice is valid for non-symmetric problems.